package com.example.bluetoothprintimage;

import java.io.File;
import java.io.IOException;
import java.io.OutputStream;

import android.app.Activity;
import android.content.Intent;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Bundle;
import android.provider.MediaStore;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;


public class MainActivity extends Activity implements OnClickListener {

	final static int IMAGE_REQUEST_CODE = 16;
	public OutputStream outputStream;
	Button selectImageBtn;
	Button connectPrinterBtn;
	Button printBtn;
	TextView statusTextView;
	ImageView logoImageView;
	String imagePath;
	
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        this.selectImageBtn = (Button) this.findViewById(R.id.selectImageBtn);
        this.connectPrinterBtn = (Button) this.findViewById(R.id.connectPrinterBtn);
        this.printBtn = (Button) findViewById(R.id.printBtn);
        this.logoImageView  = (ImageView) this.findViewById(R.id.logoImageView);
        this.statusTextView = (TextView) this.findViewById(R.id.statusTextView);
        
        this.selectImageBtn.setOnClickListener(this);
        this.connectPrinterBtn.setOnClickListener(this);
        this.printBtn.setOnClickListener(this);
        
    }


   

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		// TODO Auto-generated method stub
		super.onActivityResult(requestCode, resultCode, data);
		
		if(IMAGE_REQUEST_CODE == requestCode && resultCode == RESULT_OK){
			Uri selectedImage = data.getData();
			String[] projection = { MediaStore.Images.Media.DATA };
			Cursor cursor = getContentResolver().query(selectedImage, projection, null, null, null);
			   
			cursor.moveToFirst();
			   
			int index = cursor.getColumnIndex(MediaStore.Images.ImageColumns.DATA); 
			   
			// get image path
			this.imagePath = cursor.getString(index);
			
			// show image
			this.showImage();
			
		}else{
			
		}
	}




	@Override
	protected void onDestroy() {
		// TODO Auto-generated method stub
		super.onDestroy();
		if(this.outputStream != null){
			try {
				
				this.outputStream.close();
				
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}




	@Override
	public void onClick(View v) {
		
		try{
			int id = v.getId();
		
			if(id == R.id.selectImageBtn){
			
				Toast.makeText(this, "Select Image", Toast.LENGTH_SHORT).show();
			
				this.showGalery();
			
			}else if( id == R.id.connectPrinterBtn){
			
				PairedDevicesDialog pairedDeviceDialog = new PairedDevicesDialog(this);
				
				if(BluetoothUtils.isDeviceSupportedBluetooth()){
					
					if(!BluetoothUtils.isBluetoothEnable(this)){
						
						BluetoothUtils.enableBlueTooth(this);
						
					}else{
						pairedDeviceDialog.show();
					}
					
				}else{
					Toast.makeText(this, "Device not supported by bluetooth", Toast.LENGTH_SHORT).show();
				}
				
			}else if( id == R.id.printBtn){
				
				PrintTool.printPhotoWithPath(imagePath, this);
				
				
			}
		}catch(Exception e){
			e.printStackTrace();
		}
		
	}
	/**
	 * show image gallery
	 */
	private void showGalery(){

		try{
			Intent intent = new Intent();
			intent.setType("image/*");
			intent.setAction(Intent.ACTION_GET_CONTENT);
			intent.putExtra("return-data", true);

			this.startActivityForResult(Intent.createChooser(intent, "Select image"),MainActivity.IMAGE_REQUEST_CODE);

		}catch(Exception e){
			e.printStackTrace();
		}
	}
	/**
	 * show image
	 */
	private void showImage(){
		File imageFile = new File(imagePath);
		Bitmap bmp = BitmapFactory.decodeFile(imageFile.getAbsolutePath());
		
		this.logoImageView.setImageBitmap(bmp);
		
	}
}
